
# Single-sequence or sequence-pair task
task_type_mapping = {
    "mnli": "pair",
    "qqp": "pair",
    "qnli": "pair",
    "sst-2": "single",
    "cola": "single",
    "rte": "pair",
    "mrpc": "pair",
}

# Control code used by CTRL as the starting token
control_code_mapping = {
    "mnli": "Wikipedia",
    "qqp": "Links",
    "qnli": "Links",
    "sst-2": "Reviews",
    "cola": "Links",
    "rte": "Wikipedia",
    "mrpc": "Wikipedia",
}

# If specified, generation will start with one of the given options
fix_start_mapping = {
    "sst-2": ["the", "this", "i", "a", "it",],
    "cola": ['Such', 'Again', 'Until', 'Her', 'These', 'Where', 'She', 'The', 'We',
             'Both', 'Under', 'At', 'Of', 'Doing', "You're", 'More', 'Between', 'All',
             'While', 'As', 'Our', 'Just', 'Once', 'His', 'Other', 'Most', 'In', 'My', 'Ours',
             'Before', 'When', 'He', 'There', 'Here', 'So', 'Because', 'You', 'Over',
             'During', 'Above', 'They', 'To', 'For', 'But', 'Only', 'Those', 'Against',
             'Your', 'After', 'Now', 'An', 'Too', 'Same', 'Its', 'From', 'Being', 'With',
             'A', 'Their', 'Each', "She's", 'It', 'No', 'Then', "It's", "You've", 'Some', 
             'Few', 'This', 'If', 'By', 'I'],
}

# Valid stop tokens used to terminate a sequence
stop_tokens_mapping = {
    "mnli": ['. '],
    "qqp": ['? ', '?\n'],
    "qnli": ['. '],
    "sst-2": ['. ', '? ', '! ', '\n'],
    "cola": ['. ', '? ', '! '],
    "rte": ['. '],
    "mrpc": ['. '],
}

# Generated sequences containing bad tokens will be discarded
bad_tokens_mapping = {
    "mnli": ['\n'],
    "qqp": ['\n'],
    "qnli": ['?', '\n'],
    "sst-2": ['\n'],
    "cola": ['"', '“', '”', '\n'],
    "rte": ['\n'],
    "mrpc": ['\n'],
}

# repetition reward/penalty parameters
repetition_mapping = {
    "mnli": {
        "entailment": [1.1, 1.1],
        "neutral": [1.5, 1.5],
        "contradiction": [1.1, 1.1],
    },
    "qqp": {
        "0": [1.2, 1.2],
        "1": [1.0, 1.4],
    },
    "qnli": {
        "entailment": [0.9, 1.2],
        "not_entailment": [0.9, 1.2],
    },
    "sst-2": {
        "0": [1.1],
        "1": [1.1],
    },
    "cola": {
        "0": [1.2],
        "1": [1.2],
    },
    "rte": {
        "entailment": [0.8, 1.1],
        "not_entailment": [1.5, 1.5],
    },
    "mrpc": {
        "1": [1.0, 1.1],
        "0": [1.1, 1.1],
    },
}

# If specified, the stop token leading to the longest sequence (instead of the shortest by default) will be used to terminate a sequence
find_last_stop_token = {
    # "sst-2"
}

# If specified, use different temperature values when generating sequences
vary_temperature = {
    # "cola": [0.1, 10]
}

# If specified, the remaining generated sequence (after one stop token) will be used to sample another sequence
extract_remaining = {
    # "qnli"
}

# If specified, allow the generated sequence to start with "\n" (otherwise, generated sequences starting with "\n" will be discarded)
allow_start_new_line = {
    "qnli"
}

prompt_mapping = {
    "mnli": {
        "entailment": ["Sentence 1 implies Sentence 2. Sentence 1:", "Sentence 2:"],
        "neutral": ["Sentence 2 supplements Sentence 1. Sentence 1:", "Sentence 2:"],
        "contradiction": ["Sentence 2 contradicts Sentence 1. Sentence 1:", "Sentence 2:"],
    },
    "qqp": {
        "0": ["Question 1 is equivalent to Question 2. Question 1:", "Question 2:"],
        "1": ["Question 1 is different than Question 1. Question 1:", "Question 2:"]
    },
    "qnli": {
        "entailment": ["Paragraph is relevant to Question 1. Question:", "Paragraph:"],
        "not_entailment": ["Paragraph is irrelevant to Question 2. Question:", "Paragraph:"],
    },
    "sst-2": {
        "0": "Rating: 1.0 negative moview review:",
        "1": "Rating: 5.0 positive moview review:",
    },
    "cola": {
        "0": "Linguistically incorrect sentence:",
        "1": "Linguistically correct sentence:",
    },
    "mrpc": {
        "1": ["Sentence 1 is equivalent to Sentence 2. Sentence 1:", "Sentence 2:"], 
        "0": ["Sentence 1 is different than Sentence 2. Sentence 1:", "Sentence 2:"]
    },
    "rte": {
        "entailment": ["Sentence 1 is equivalent to Sentence 2. Sentence 1:", "Sentence 2:"], 
        "not_entailment": ["Sentence 1 is different than Sentence 2. Sentence 1:", "Sentence 2:"]
    },
}
